"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.setSelectionRange = setSelectionRange;

var _utils = require("../../utils");

function setSelectionRange({
  currentElement,
  newValue,
  newSelectionStart
}) {
  // if we *can* change the selection start, then we will if the new value
  // is the same as the current value (so it wasn't programatically changed
  // when the fireEvent.input was triggered).
  // The reason we have to do this at all is because it actually *is*
  // programmatically changed by fireEvent.input, so we have to simulate the
  // browser's default behavior
  const el = currentElement();
  const value = (0, _utils.getValue)(el);

  if (value === newValue) {
    (0, _utils.setSelectionRangeIfNecessary)(el, newSelectionStart, newSelectionStart);
  } else {
    // If the currentValue is different than the expected newValue and we *can*
    // change the selection range, than we should set it to the length of the
    // currentValue to ensure that the browser behavior is mimicked.
    (0, _utils.setSelectionRangeIfNecessary)(el, value.length, value.length);
  }
}